function varargout = exchange2D(Sys,Exp,Opt)
%Wrapper for exchange() function for temperature swept spectra
%returns concatenated spectrum for all temperatures
%for using with esfit() function
%   Sys.dH - the array of activation enthalpies
%   Sys.dS - the array of activation entropies
%   Sys.km - matrix rate constants indexes
%   Sys.mwFreq - the array of MW Frequencies, uses for drift compensation
%   Exp.Temperature - the array of temperatures
%
if (nargin<2), Exp = struct; end
if (nargin<3), Opt = struct; end
if iscell(Sys), error('Multicomponent spectra does not support yet'); end
if ~isstruct(Exp), error('Experiment structure Exp is missing.'); end
spc=[];
Sys1=Sys;
Exp1=Exp;
nSpec=size(Exp.Temperature,2);
if isfield(Exp1,'nPoints'),Exp1.nPoints=Exp1.nPoints/nSpec; %overcome esfit limitation
for i=1:nSpec
    if isfield(Sys,'mwFreq'), Sys1.mwFreq=Sys.mwFreq(i); end
    Exp1.Temperature=Exp.Temperature(i);
    
    if isfield(Sys,'lb')&&numel(Sys.lb)>1,Sys1.lb=Sys.lb(i);end
    if numel(Sys.lw)>1,Sys1.lw=Sys.lw(i);end
        
    spc1=exchange(Sys1,Exp1,Opt);
    spc=cat(2,spc,spc1);
    
end
% Output
%-------------------------------------------------------------

varargout = {spc};
end

